import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _inherits from "@babel/runtime/helpers/inherits";
import _createSuper from "@babel/runtime/helpers/createSuper";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { __decorate } from "tslib";
import React, { cloneElement, Component, isValidElement } from 'react';
import { observer } from 'mobx-react';
import { action, isArrayLike, observable, runInAction, toJS } from 'mobx';
import uniq from 'lodash/uniq';
import pull from 'lodash/pull';
import noop from 'lodash/noop';
import map from 'lodash/map';
import isObject from 'lodash/isObject';
import isEnumEmpty from 'lodash/isEmpty';
import isNumber from 'lodash/isNumber';
import isFunction from 'lodash/isFunction';
import isEqual from 'lodash/isEqual';
import isArray from 'lodash/isArray';
import isString from 'lodash/isString';
import omit from 'lodash/omit';
import debounce from 'lodash/debounce';
import difference from 'lodash/difference';
import { getProPrefixCls } from '../../../../es/configure/utils';
import { pxToRem } from '../../../../es/_util/UnitConvertor';
import Icon from '../../../../es/icon';
import KeyCode from '../../../../es/_util/KeyCode';
import { Action } from '../../../../es/trigger/enum';
import DataSet from '../../data-set/DataSet';
import { DataSetSelection, FieldIgnore, FieldType, RecordStatus } from '../../data-set/enum';
import Button from '../../button';
import Dropdown from '../../dropdown';
import TextField from '../../text-field';
import Tooltip from '../../tooltip';
import TableContext from '../TableContext';
import { $l } from '../../locale-context';
import autobind from '../../_util/autobind';
import _isEmpty from '../../_util/isEmpty';
import FieldList from '../../table/query-bar/FieldList';
import ColumnFilter from '../tool-bar/ColumnFilter';
import { ValueChangeAction } from '../../text-field/enum';
import { iteratorFilterToArray } from '../../_util/iteratorUtils';
import QuickFilterMenu from '../../table/query-bar/quick-filter/QuickFilterMenu';
import QuickFilterMenuContext from '../../table/query-bar/quick-filter/QuickFilterMenuContext';
import { ConditionDataSet, QuickFilterDataSet } from '../../table/query-bar/quick-filter/QuickFilterDataSet';
/**
 * 当前数据是否有值并需要选中
 * @param data
 */

function isSelect(data) {
  if (isObject(data[1])) {
    return !isEnumEmpty(data[1]);
  }

  return data[0] !== '__dirty' && !_isEmpty(data[1]);
}

export function isEqualDynamicProps(originalValue, newValue, dataSet, record) {
  if (isEqual(newValue, originalValue)) {
    return true;
  }

  if (isObject(newValue) && isObject(originalValue) && Object.keys(newValue).length) {
    return Object.keys(newValue).every(function (key) {
      var value = newValue[key];
      var oldValue = originalValue[key];

      if (oldValue === value) {
        return true;
      }

      if (_isEmpty(oldValue) && _isEmpty(value)) {
        return true;
      }

      if (isNumber(oldValue) || isNumber(value)) {
        var oEp = isNumber(oldValue) ? _isEmpty(oldValue) : isEnumEmpty(oldValue);
        var nEp = isNumber(value) ? _isEmpty(value) : isEnumEmpty(value);

        if (oEp && nEp) {
          return true;
        }

        return String(oldValue) === String(value);
      }

      var field = dataSet.getField(key);

      if (field && field.get('lovCode') && oldValue && value) {
        var valueField = dataSet.getField(key).get('valueField', record);
        var textField = dataSet.getField(key).get('textField', record);
        return value[valueField] === oldValue[valueField] && value[textField] === oldValue[textField];
      }

      return isEqual(oldValue, value);
    });
  }

  return isEqual(newValue, originalValue);
}

function getQueryData(queryDataSet) {
  var current = queryDataSet.current;

  if (current) {
    var queryData = omit(current.toData(true), ['__dirty']);
    return Object.keys(queryData).reduce(function (p, key) {
      var value = queryData[key];

      if (!_isEmpty(value)) {
        p[key] = value;
      }

      return p;
    }, {});
  }

  return {};
}

export var CONDITIONSTATUS = '__CONDITIONSTATUS__';
export var SELECTFIELDS = '__SELECTFIELDS__';
export var MENUDATASET = '__MENUDATASET__';
export var CONDITIONDATASET = '__CONDITIONDATASET__';
export var OPTIONDATASET = '__OPTIONDATASET__';
export var FILTERMENUDATASET = '__FILTERMENUDATASET__';
export var SELECTCHANGE = '__SELECTCHANGE__';

var TableDynamicFilterBar = /*#__PURE__*/function (_Component) {
  _inherits(TableDynamicFilterBar, _Component);

  var _super = _createSuper(TableDynamicFilterBar);

  function TableDynamicFilterBar(props, context) {
    var _this;

    _classCallCheck(this, TableDynamicFilterBar);

    _this = _super.call(this, props, context);
    _this.refDropdown = null;
    _this.refFilterWrapper = null;
    _this.refSingleWrapper = null;
    _this.refEditors = new Map();
    _this.originalConditionFields = [];
    _this.enterNum = 0;

    _this.handleClickOut = function (e) {
      if (_this.refDropdown && !_this.refDropdown.contains(e.target)) {
        _this.fieldSelectHidden = true;
      }
    };

    _this.setOriginalConditionFields = function (code) {
      var queryDataSet = _this.props.queryDataSet;

      if (!code) {
        _this.originalConditionFields = [];
      } else {
        var codes = Array.isArray(code) ? code : [code];
        _this.originalConditionFields = uniq([].concat(_toConsumableArray(_this.originalConditionFields), _toConsumableArray(codes)));
      }

      queryDataSet.setState(SELECTFIELDS, _toConsumableArray(_this.originalConditionFields));
    };
    /**
     * 勾选
     * @param code
     * @param record
     */


    _this.handleSelect = function (code, record) {
      var queryDataSet = _this.props.queryDataSet;
      var codes = Array.isArray(code) ? code : [code];
      var selectFields = queryDataSet.getState(SELECTFIELDS) || [];
      queryDataSet.setState(SELECTFIELDS, uniq([].concat(_toConsumableArray(selectFields), _toConsumableArray(codes))));
      var shouldUpdate = queryDataSet.getState(SELECTFIELDS).length !== _this.originalConditionFields.length || !!difference(toJS(queryDataSet.getState(SELECTFIELDS)), toJS(_this.originalConditionFields)).length;
      var isDirty = record ? record.dirty : false;

      _this.setConditionStatus(shouldUpdate || isDirty ? RecordStatus.update : RecordStatus.sync);

      queryDataSet.setState(SELECTCHANGE, shouldUpdate);
    };
    /**
     * 取消勾选
     * @param code
     */


    _this.handleUnSelect = function (code) {
      var queryDataSet = _this.props.queryDataSet;
      var codes = Array.isArray(code) ? code : [code];

      if (queryDataSet) {
        var current = queryDataSet.current;

        if (current) {
          codes.forEach(function (name) {
            return current.set(name, undefined);
          });
        }
      }

      var selectFields = queryDataSet.getState(SELECTFIELDS) || [];
      queryDataSet.setState(SELECTFIELDS, pull.apply(void 0, [_toConsumableArray(selectFields)].concat(_toConsumableArray(codes))));
      var shouldUpdate = queryDataSet.getState(SELECTFIELDS).length !== _this.originalConditionFields.length || !!difference(toJS(queryDataSet.getState(SELECTFIELDS)), toJS(_this.originalConditionFields)).length;

      _this.setConditionStatus(shouldUpdate ? RecordStatus.update : RecordStatus.sync);

      queryDataSet.setState(SELECTCHANGE, shouldUpdate);
    };

    runInAction(function () {
      _this.fieldSelectHidden = true;
      _this.expand = true;
    });
    return _this;
  }

  _createClass(TableDynamicFilterBar, [{
    key: "prefixCls",
    get: function get() {
      if ('prefixCls' in this.props) {
        var prefixCls = this.props.prefixCls;
        return prefixCls;
      }

      var _this$context$tableSt = this.context.tableStore.proPrefixCls,
          proPrefixCls = _this$context$tableSt === void 0 ? getProPrefixCls('performance-table') : _this$context$tableSt;
      return proPrefixCls;
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      var fuzzyQueryOnly = this.props.fuzzyQueryOnly;

      if (!fuzzyQueryOnly) {
        this.processDataSetListener(true);
        document.addEventListener('click', this.handleClickOut);

        if (this.isSingleLineOpt() && this.refSingleWrapper) {
          var _this$refSingleWrappe = this.refSingleWrapper.getBoundingClientRect(),
              height = _this$refSingleWrappe.height;

          var _this$refSingleWrappe2 = this.refSingleWrapper.children[0].children[0].getBoundingClientRect(),
              childHeight = _this$refSingleWrappe2.height;

          runInAction(function () {
            _this2.showExpandIcon = height > childHeight + 18;
          });
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      var fuzzyQueryOnly = this.props.fuzzyQueryOnly;

      if (!fuzzyQueryOnly) {
        document.removeEventListener('click', this.handleClickOut);
        this.processDataSetListener(false);
      }
    }
  }, {
    key: "processDataSetListener",
    value: function processDataSetListener(flag) {
      var queryDataSet = this.props.queryDataSet;

      if (queryDataSet) {
        var handler = flag ? queryDataSet.addEventListener : queryDataSet.removeEventListener;
        handler.call(queryDataSet, 'validate', this.handleDataSetValidate);
        handler.call(queryDataSet, 'update', this.handleDataSetUpdate);
        handler.call(queryDataSet, 'create', this.handleDataSetCreate);
      }
    }
    /**
     * queryDataSet 查询前校验事件 触发展开动态字段
     * @param dataSet 查询DS
     * @param result
     */

  }, {
    key: "handleDataSetValidate",
    value: function () {
      var _handleDataSetValidate = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
        var _this3 = this;

        var dataSet, result, refSingleWrapper;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                dataSet = _ref.dataSet, result = _ref.result;
                _context.next = 3;
                return result;

              case 3:
                if (_context.sent) {
                  _context.next = 7;
                  break;
                }

                runInAction(function () {
                  var current = dataSet.current;
                  dataSet.fields.forEach(function (field, key) {
                    if (!field.isValid(current)) {
                      _this3.handleSelect(key);
                    }
                  });
                  _this3.expand = true;
                });
                refSingleWrapper = this.refSingleWrapper;

                if (refSingleWrapper) {
                  refSingleWrapper.style.height = '';
                  refSingleWrapper.style.overflow = '';
                }

              case 7:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function handleDataSetValidate(_x) {
        return _handleDataSetValidate.apply(this, arguments);
      }

      return handleDataSetValidate;
    }()
  }, {
    key: "setConditionStatus",
    value: function setConditionStatus(value, orglValue) {
      var queryDataSet = this.props.queryDataSet;
      queryDataSet.setState(CONDITIONSTATUS, value);

      if (value === RecordStatus.sync && orglValue) {
        this.originalValue = orglValue;
      }
    }
    /**
     * 筛选条件更新 触发表格查询
     */

  }, {
    key: "handleDataSetUpdate",
    value: function handleDataSetUpdate(_ref2) {
      var record = _ref2.record;
      var _this$props = this.props,
          dataSet = _this$props.dataSet,
          queryDataSet = _this$props.queryDataSet,
          _this$props$onQuery = _this$props.onQuery,
          onQuery = _this$props$onQuery === void 0 ? noop : _this$props$onQuery,
          autoQuery = _this$props.autoQuery;
      var status = RecordStatus.update;

      if (record) {
        status = isEqualDynamicProps(this.originalValue, omit(record.toData(), ['__dirty']), queryDataSet, record) ? RecordStatus.sync : RecordStatus.update;
      }

      this.setConditionStatus(status);

      if (autoQuery) {
        dataSet.query();
        onQuery();
      }
    }
    /**
     * queryDS 新建，初始勾选值
     */

  }, {
    key: "handleDataSetCreate",
    value: function handleDataSetCreate(props) {
      var _this4 = this;

      var dataSet = props.dataSet,
          record = props.record;
      var queryDataSet = this.props.queryDataSet;
      var originalValue = omit(record.toData(), ['__dirty']);
      var conditionData = Object.entries(originalValue);
      this.originalValue = originalValue;
      this.originalConditionFields = [];
      var fields = dataSet.fields;
      map(conditionData, function (data) {
        var name = data[0];

        if (!fields.has(data[0]) && isObject(data[1]) && !isEnumEmpty(data[1]) && !isArray(data[1])) {
          name = "".concat(data[0], ".").concat(Object.keys(data[1])[0]);
        }

        if (isSelect(data) && !(queryDataSet.getState(SELECTFIELDS) || []).includes(name)) {
          var field = dataSet.getField(name);

          if (!field || !field.get('bind', record)) {
            _this4.originalConditionFields.push(name);

            _this4.handleSelect(name);
          }
        }
      });
      this.initMenuDataSet();
    }
  }, {
    key: "initMenuDataSet",
    value: function () {
      var _initMenuDataSet = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
        var _this5 = this;

        var _this$props2, queryDataSet, dataSet, dynamicFilterBar, searchCode, getConfig, searchCodes, menuDataSet, conditionDataSet, optionDataSet, filterMenuDataSet, result, menuRecord, current;

        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _this$props2 = this.props, queryDataSet = _this$props2.queryDataSet, dataSet = _this$props2.dataSet, dynamicFilterBar = _this$props2.dynamicFilterBar, searchCode = _this$props2.searchCode;
                getConfig = this.context.tableStore.getConfig;
                searchCodes = dynamicFilterBar && dynamicFilterBar.searchCode || searchCode;
                menuDataSet = new DataSet(QuickFilterDataSet({
                  searchCode: searchCodes,
                  queryDataSet: queryDataSet,
                  tableFilterAdapter: this.tableFilterAdapter
                }), {
                  getConfig: getConfig
                });
                conditionDataSet = new DataSet(ConditionDataSet(), {
                  getConfig: getConfig
                });
                optionDataSet = new DataSet({
                  selection: DataSetSelection.single
                }, {
                  getConfig: getConfig
                });
                filterMenuDataSet = new DataSet({
                  autoCreate: true,
                  fields: [{
                    name: 'filterName',
                    type: FieldType.string,
                    textField: 'searchName',
                    valueField: 'searchId',
                    options: optionDataSet,
                    ignore: FieldIgnore.always
                  }]
                }, {
                  getConfig: getConfig
                });
                queryDataSet.setState(MENUDATASET, menuDataSet);
                queryDataSet.setState(CONDITIONDATASET, conditionDataSet);
                queryDataSet.setState(OPTIONDATASET, optionDataSet);
                queryDataSet.setState(FILTERMENUDATASET, filterMenuDataSet);
                _context2.next = 13;
                return menuDataSet.query();

              case 13:
                result = _context2.sent;

                if (optionDataSet) {
                  optionDataSet.loadData(result);
                }

                menuRecord = menuDataSet.current;

                if (menuRecord) {
                  conditionDataSet.loadData(menuRecord.get('conditionList'));
                }

                if (result && result.length) {
                  runInAction(function () {
                    _this5.shouldLocateData = true;
                  });
                } else {
                  current = filterMenuDataSet.current;
                  if (current) current.set('filterName', undefined);
                  runInAction(function () {
                    _this5.shouldLocateData = true;
                  });

                  if (dataSet.props.autoQuery) {
                    dataSet.query();
                  }
                }

              case 18:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function initMenuDataSet() {
        return _initMenuDataSet.apply(this, arguments);
      }

      return initMenuDataSet;
    }()
    /**
     * tableFilterSuffix 预留自定义区域
     */

  }, {
    key: "renderSuffix",
    value: function renderSuffix() {
      var _this$context = this.context,
          tableStore = _this$context.tableStore,
          proPrefixCls = _this$context.tableStore.proPrefixCls;
      var _this$props3 = this.props,
          dynamicFilterBar = _this$props3.dynamicFilterBar,
          queryDataSet = _this$props3.queryDataSet,
          dataSet = _this$props3.dataSet;
      var suffixes = dynamicFilterBar && dynamicFilterBar.suffixes || tableStore.getConfig('tableFilterSuffix');
      var children = [];

      if (suffixes && suffixes.length) {
        suffixes.forEach(function (suffix) {
          if (suffix === 'filter') {
            children.push( /*#__PURE__*/React.createElement(ColumnFilter, {
              prefixCls: proPrefixCls
            }));
          } else if ( /*#__PURE__*/isValidElement(suffix)) {
            children.push(suffix);
          } else if (isFunction(suffix)) {
            children.push(suffix({
              queryDataSet: queryDataSet,
              dataSet: dataSet
            }));
          }
        });
        return /*#__PURE__*/React.createElement("div", {
          className: "".concat(proPrefixCls, "-dynamic-filter-bar-suffix")
        }, children);
      }
    }
  }, {
    key: "getPrefix",
    value: function getPrefix() {
      var proPrefixCls = this.context.tableStore.proPrefixCls;
      var _this$props4 = this.props,
          dynamicFilterBar = _this$props4.dynamicFilterBar,
          queryDataSet = _this$props4.queryDataSet,
          dataSet = _this$props4.dataSet;
      var prefixes = dynamicFilterBar && dynamicFilterBar.prefixes;
      var children = [];

      if (prefixes && prefixes.length) {
        prefixes.forEach(function (prefix) {
          if (isString(prefix) && prefix === 'filter') {
            children.push( /*#__PURE__*/React.createElement(ColumnFilter, {
              prefixCls: proPrefixCls
            }));
          } else if ( /*#__PURE__*/isValidElement(prefix)) {
            children.push(prefix);
          } else if (isFunction(prefix)) {
            children.push(prefix({
              queryDataSet: queryDataSet,
              dataSet: dataSet
            }));
          }
        });
        return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
          className: "".concat(proPrefixCls, "-dynamic-filter-bar-prefix")
        }, children), /*#__PURE__*/React.createElement("span", {
          className: "".concat(proPrefixCls, "-filter-search-divide")
        }));
      }

      return null;
    }
    /**
     * 注入 onEnterDown 事件
     * @param element
     * @param name
     */

  }, {
    key: "createFields",
    value: function createFields(element, name) {
      var _this6 = this;

      var onEnterDown = element.props.onEnterDown;

      if (onEnterDown && isFunction(onEnterDown)) {
        return element;
      }

      var props = {
        onEnterDown: function onEnterDown() {
          _this6.handleQuery();
        },
        ref: function ref(node) {
          return _this6.refEditors.set(name, node);
        }
      };
      return /*#__PURE__*/cloneElement(element, props);
    }
    /**
     * 判断查询值是否为空
     * @param value
     */

  }, {
    key: "isEmpty",
    value: function isEmpty(value) {
      return isArrayLike(value) ? !value.length : _isEmpty(value);
    }
  }, {
    key: "tableFilterAdapter",
    get: function get() {
      var dynamicFilterBar = this.props.dynamicFilterBar;
      var tableStore = this.context.tableStore;
      return dynamicFilterBar && dynamicFilterBar.tableFilterAdapter || tableStore.getConfig('tableFilterAdapter');
    }
    /**
     * 是否单行操作
     */

  }, {
    key: "isSingleLineOpt",
    value: function isSingleLineOpt() {
      var fuzzyQuery = this.props.fuzzyQuery;
      return !(fuzzyQuery || this.tableFilterAdapter);
    }
  }, {
    key: "renderRefreshBtn",
    value: function renderRefreshBtn() {
      var _this7 = this;

      var proPrefixCls = this.context.tableStore.proPrefixCls;
      return /*#__PURE__*/React.createElement("span", {
        className: "".concat(proPrefixCls, "-filter-menu-query"),
        onClick: function onClick(e) {
          e.stopPropagation();
          var _this7$props = _this7.props,
              dataSet = _this7$props.dataSet,
              queryDataSet = _this7$props.queryDataSet,
              _this7$props$onRefres = _this7$props.onRefresh,
              onRefresh = _this7$props$onRefres === void 0 ? noop : _this7$props$onRefres;
          var data = getQueryData(queryDataSet);
          onRefresh({
            dataSet: dataSet,
            queryDataSet: queryDataSet,
            data: data,
            params: _this7.searchText
          });
        }
      }, /*#__PURE__*/React.createElement(Tooltip, {
        title: $l('Table', 'refresh')
      }, /*#__PURE__*/React.createElement(Icon, {
        type: "refresh"
      })));
    }
    /**
     * 渲染展开逻辑
     * @param hidden 是否隐藏全部
     */

  }, {
    key: "getExpandNode",
    value: function getExpandNode(hidden) {
      var _this8 = this;

      var proPrefixCls = this.context.tableStore.proPrefixCls;
      var refreshBtn = this.props.refreshBtn;
      if (!this.showExpandIcon && !hidden) return refreshBtn ? this.renderRefreshBtn() : null;
      return /*#__PURE__*/React.createElement("span", {
        className: "".concat(proPrefixCls, "-filter-menu-expand"),
        onClick: function onClick() {
          var refSingleWrapper = _this8.refSingleWrapper;

          if (refSingleWrapper) {
            var _refSingleWrapper$get = refSingleWrapper.getBoundingClientRect(),
                height = _refSingleWrapper$get.height;

            var _refSingleWrapper$chi = refSingleWrapper.children[0].children[0].getBoundingClientRect(),
                childHeight = _refSingleWrapper$chi.height;

            runInAction(function () {
              _this8.expand = hidden ? height <= 0 : height <= childHeight + 18;
            });

            if (hidden && height) {
              // 收起全部
              refSingleWrapper.style.display = 'none';
            } else {
              refSingleWrapper.style.display = 'flex';
              refSingleWrapper.style.height = '';
              refSingleWrapper.style.overflow = '';
            }

            if (height > childHeight + 18 && !hidden) {
              // 收起留一行高度
              refSingleWrapper.style.height = pxToRem(childHeight + 18, true) || '';
              refSingleWrapper.style.overflow = 'hidden';
            } else {
              refSingleWrapper.style.height = '';
              refSingleWrapper.style.overflow = '';
            }
          }
        }
      }, refreshBtn ? this.renderRefreshBtn() : null, this.expand ? /*#__PURE__*/React.createElement(Tooltip, {
        title: $l('Table', 'collapse')
      }, /*#__PURE__*/React.createElement(Icon, {
        type: "baseline-arrow_drop_up"
      })) : /*#__PURE__*/React.createElement(Tooltip, {
        title: $l('Table', 'expand_button')
      }, /*#__PURE__*/React.createElement(Icon, {
        type: "baseline-arrow_drop_down"
      })));
    }
    /**
     * 渲染模糊搜索
     */

  }, {
    key: "getFuzzyQuery",
    value: function getFuzzyQuery() {
      var _this9 = this;

      var fuzzyQuery = this.props.fuzzyQuery;
      if (!fuzzyQuery) return null;
      var _this$props5 = this.props,
          dataSet = _this$props5.dataSet,
          dynamicFilterBar = _this$props5.dynamicFilterBar,
          autoQueryAfterReset = _this$props5.autoQueryAfterReset,
          fuzzyQueryPlaceholder = _this$props5.fuzzyQueryPlaceholder,
          _this$props5$onReset = _this$props5.onReset,
          onReset = _this$props5$onReset === void 0 ? noop : _this$props5$onReset;
      var _this$context2 = this.context,
          tableStore = _this$context2.tableStore,
          _this$context2$tableS = _this$context2.tableStore,
          proPrefixCls = _this$context2$tableS.proPrefixCls,
          node = _this$context2$tableS.node,
          highlightRowIndexs = _this$context2$tableS.highlightRowIndexs;
      var searchText = dynamicFilterBar && dynamicFilterBar.searchText || tableStore.getConfig('tableFilterSearchText') || 'params';
      var placeholder = fuzzyQueryPlaceholder || $l('Table', 'enter_search_content');
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(proPrefixCls, "-filter-search")
      }, /*#__PURE__*/React.createElement(TextField, {
        style: {
          width: 280
        },
        clearButton: true,
        placeholder: placeholder,
        prefix: /*#__PURE__*/React.createElement(Icon, {
          type: "search"
        }),
        value: this.searchText,
        valueChangeAction: ValueChangeAction.input,
        onChange: debounce(function (value) {
          runInAction(function () {
            _this9.searchText = value || '';

            if (dynamicFilterBar && dynamicFilterBar.quickSearch) {
              tableStore.highlightRowIndexs = [];
              tableStore.searchText = value || '';
              node.forceUpdate();
            }
          });
          dataSet.setQueryParameter(searchText, value);

          _this9.handleQuery();
        }, 500),
        onKeyDown: function onKeyDown(e) {
          if (e.keyCode === KeyCode.ENTER && dynamicFilterBar && dynamicFilterBar.quickSearch) {
            e.preventDefault();

            var rows = _toConsumableArray(new Set(highlightRowIndexs));

            node.scrollTop(rows[_this9.enterNum] * node.getRowHeight());
            _this9.enterNum += 1;

            if (_this9.enterNum + 1 > rows.length) {
              _this9.enterNum = 0;
            }
          }
        },
        onClear: function onClear() {
          runInAction(function () {
            _this9.searchText = '';

            if (dynamicFilterBar && dynamicFilterBar.quickSearch) {
              tableStore.searchText = '';
              tableStore.highlightRowIndexs = [];
              node.forceUpdate();
            }
          });
          onReset();

          if (autoQueryAfterReset) {
            dataSet.setQueryParameter(searchText, undefined);

            _this9.handleQuery(true);
          }
        }
      }));
    }
    /**
     * 渲染重置按钮
     */

  }, {
    key: "getResetButton",
    value: function getResetButton() {
      var _this10 = this;

      var proPrefixCls = this.context.tableStore.proPrefixCls;
      var _this$props6 = this.props,
          queryDataSet = _this$props6.queryDataSet,
          autoQueryAfterReset = _this$props6.autoQueryAfterReset,
          _this$props6$onReset = _this$props6.onReset,
          onReset = _this$props6$onReset === void 0 ? noop : _this$props6$onReset;
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(proPrefixCls, "-filter-buttons")
      }, queryDataSet.getState(CONDITIONSTATUS) === RecordStatus.update && /*#__PURE__*/React.createElement(Button, {
        onClick: function onClick() {
          if (queryDataSet) {
            var current = queryDataSet.current;

            if (current) {
              current.reset();

              _this10.handleDataSetCreate({
                dataSet: queryDataSet,
                record: current
              });
            }
          }

          _this10.setConditionStatus(RecordStatus.sync);

          onReset();

          if (autoQueryAfterReset) {
            _this10.handleQuery();
          }
        }
      }, $l('Table', 'reset_button')));
    }
    /**
     * 筛选头
     * fuzzyQuery + quickFilterMenu + resetButton + buttons
     */

  }, {
    key: "getFilterMenu",
    value: function getFilterMenu() {
      var proPrefixCls = this.context.tableStore.proPrefixCls;
      var _this$props7 = this.props,
          queryFields = _this$props7.queryFields,
          queryDataSet = _this$props7.queryDataSet,
          dataSet = _this$props7.dataSet,
          dynamicFilterBar = _this$props7.dynamicFilterBar,
          searchCode = _this$props7.searchCode,
          autoQuery = _this$props7.autoQuery,
          fuzzyQueryOnly = _this$props7.fuzzyQueryOnly;
      var prefix = this.getPrefix();
      var suffix = this.renderSuffix();
      var fuzzyQuery = this.getFuzzyQuery();

      if (fuzzyQueryOnly) {
        return /*#__PURE__*/React.createElement("div", {
          className: "".concat(proPrefixCls, "-filter-menu")
        }, prefix, fuzzyQuery, suffix);
      }

      if (queryDataSet && queryFields.length) {
        var _prefix = this.getPrefix();

        var _fuzzyQuery = this.getFuzzyQuery();

        var searchCodes = dynamicFilterBar && dynamicFilterBar.searchCode || searchCode;
        var quickFilterMenu = this.tableFilterAdapter && searchCodes ? /*#__PURE__*/React.createElement(QuickFilterMenuContext.Provider, {
          value: {
            autoQuery: autoQuery,
            prefixCls: proPrefixCls,
            expand: this.expand,
            dataSet: dataSet,
            queryDataSet: queryDataSet,
            onChange: this.handleSelect,
            conditionStatus: queryDataSet.getState(CONDITIONSTATUS),
            onStatusChange: this.setConditionStatus,
            selectFields: queryDataSet.getState(SELECTFIELDS),
            onOriginalChange: this.setOriginalConditionFields,
            menuDataSet: queryDataSet.getState(MENUDATASET),
            filterMenuDataSet: queryDataSet.getState(FILTERMENUDATASET),
            conditionDataSet: queryDataSet.getState(CONDITIONDATASET),
            optionDataSet: queryDataSet.getState(OPTIONDATASET),
            shouldLocateData: this.shouldLocateData
          }
        }, /*#__PURE__*/React.createElement(QuickFilterMenu, null)) : null;
        var resetButton = this.isSingleLineOpt() || this.tableFilterAdapter ? null : this.getResetButton();
        return /*#__PURE__*/React.createElement("div", {
          className: "".concat(proPrefixCls, "-filter-menu")
        }, _prefix, _fuzzyQuery, quickFilterMenu, resetButton, this.isSingleLineOpt() ? null : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
          className: "".concat(proPrefixCls, "-filter-search-divide")
        }), this.getExpandNode(true)), suffix);
      }
    }
    /**
     * 渲染查询条
     */

  }, {
    key: "getQueryBar",
    value: function getQueryBar() {
      var _this11 = this;

      var proPrefixCls = this.context.tableStore.proPrefixCls;
      var _this$props8 = this.props,
          _this$props8$queryFie = _this$props8.queryFieldsLimit,
          queryFieldsLimit = _this$props8$queryFie === void 0 ? 3 : _this$props8$queryFie,
          queryFields = _this$props8.queryFields,
          queryDataSet = _this$props8.queryDataSet,
          fuzzyQueryOnly = _this$props8.fuzzyQueryOnly;
      var selectFields = queryDataSet.getState(SELECTFIELDS) || [];

      if (fuzzyQueryOnly) {
        return /*#__PURE__*/React.createElement("div", {
          key: "query_bar",
          className: "".concat(proPrefixCls, "-dynamic-filter-bar")
        }, this.getFilterMenu());
      }

      var singleLineModeAction = this.isSingleLineOpt() ? /*#__PURE__*/React.createElement("div", {
        className: "".concat(proPrefixCls, "-dynamic-filter-bar-single-action")
      }, this.getResetButton(), this.getExpandNode(false)) : null;

      if (queryDataSet && queryFields.length) {
        return /*#__PURE__*/React.createElement("div", {
          key: "query_bar",
          className: "".concat(proPrefixCls, "-dynamic-filter-bar")
        }, this.getFilterMenu(), /*#__PURE__*/React.createElement("div", {
          className: "".concat(proPrefixCls, "--dynamic-filter-single-wrapper"),
          ref: function ref(node) {
            return _this11.refSingleWrapper = node;
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "".concat(proPrefixCls, "-filter-wrapper")
        }, queryFields.slice(0, queryFieldsLimit).map(function (element) {
          var _element$props = element.props,
              name = _element$props.name,
              hidden = _element$props.hidden;
          if (hidden) return null;
          var queryField = queryDataSet.getField(name);
          var itemClassName = "".concat(proPrefixCls, "-filter-item");
          return /*#__PURE__*/React.createElement("div", {
            className: "".concat(proPrefixCls, "-filter-content"),
            key: name,
            onClick: function onClick() {
              return _this11.refEditors.get(name).focus();
            }
          }, /*#__PURE__*/React.createElement("span", {
            className: "".concat(proPrefixCls, "-filter-label")
          }, queryField && queryField.get('label')), /*#__PURE__*/React.createElement("span", {
            className: itemClassName
          }, _this11.createFields(element, name)));
        }), queryFields.slice(queryFieldsLimit).map(function (element) {
          var _element$props2 = element.props,
              name = _element$props2.name,
              hidden = _element$props2.hidden;
          if (hidden) return null;
          var queryField = queryDataSet.getField(name);

          if (selectFields.includes(name)) {
            return /*#__PURE__*/React.createElement("div", {
              className: "".concat(proPrefixCls, "-filter-content"),
              key: name,
              onClick: function onClick() {
                var editor = _this11.refEditors.get(name);

                if (editor && Object.prototype.hasOwnProperty.call(editor, 'focus')) {
                  _this11.refEditors.get(name).focus();
                }
              }
            }, /*#__PURE__*/React.createElement(Icon, {
              type: "cancel",
              className: "".concat(proPrefixCls, "-filter-item-close"),
              onClick: function onClick() {
                _this11.handleUnSelect([name]);
              }
            }), /*#__PURE__*/React.createElement("span", {
              className: "".concat(proPrefixCls, "-filter-label")
            }, queryField && queryField.get('label')), /*#__PURE__*/React.createElement("span", {
              className: "".concat(proPrefixCls, "-filter-item")
            }, _this11.createFields(element, name)));
          }

          return null;
        }), queryFieldsLimit < queryFields.length && /*#__PURE__*/React.createElement("div", {
          className: "".concat(proPrefixCls, "-filter-item")
        }, /*#__PURE__*/React.createElement(Dropdown, {
          visible: !this.fieldSelectHidden,
          overlay: /*#__PURE__*/React.createElement("div", {
            role: "none",
            ref: function ref(node) {
              return _this11.refDropdown = node;
            },
            onClick: function onClick(e) {
              e.stopPropagation();
            }
          }, /*#__PURE__*/React.createElement(FieldList, {
            groups: [{
              title: $l('Table', 'predefined_fields'),
              fields: iteratorFilterToArray(queryDataSet.fields.values(), function (f) {
                return !f.get('bind') && !f.get('name').includes('__tls');
              }).slice(queryFieldsLimit)
            }],
            prefixCls: "".concat(proPrefixCls, "-filter-list") || 'c7n-pro-table-filter-list',
            closeMenu: function closeMenu() {
              return runInAction(function () {
                return _this11.fieldSelectHidden = true;
              });
            },
            value: selectFields,
            onSelect: this.handleSelect,
            onUnSelect: this.handleUnSelect
          })),
          trigger: [Action.click]
        }, /*#__PURE__*/React.createElement("span", {
          className: "".concat(proPrefixCls, "-add-fields"),
          onClick: function onClick(e) {
            e.nativeEvent.stopImmediatePropagation();
            runInAction(function () {
              _this11.fieldSelectHidden = false;
            });
          }
        }, /*#__PURE__*/React.createElement(Icon, {
          type: "add"
        }), $l('Table', 'add_filter'))))), singleLineModeAction));
      }

      return null;
    }
  }, {
    key: "handleQuery",
    value: function handleQuery(collapse) {
      var _this$props9 = this.props,
          dataSet = _this$props9.dataSet,
          queryDataSet = _this$props9.queryDataSet,
          _this$props9$onQuery = _this$props9.onQuery,
          onQuery = _this$props9$onQuery === void 0 ? noop : _this$props9$onQuery,
          autoQuery = _this$props9.autoQuery;

      if (autoQuery) {
        dataSet.query();
      }

      if (!collapse) {
        var data = getQueryData(queryDataSet);
        onQuery({
          dataSet: dataSet,
          queryDataSet: queryDataSet,
          data: data,
          params: this.searchText
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      return this.getQueryBar();
    }
  }], [{
    key: "contextType",
    get: function get() {
      return TableContext;
    }
  }]);

  return TableDynamicFilterBar;
}(Component);

TableDynamicFilterBar.defaultProps = {
  queryFieldsLimit: 3,
  autoQueryAfterReset: true,
  fuzzyQuery: true,
  fuzzyQueryOnly: false,
  autoQuery: true,
  refreshBtn: true
};

__decorate([observable], TableDynamicFilterBar.prototype, "moreFields", void 0);

__decorate([observable], TableDynamicFilterBar.prototype, "fieldSelectHidden", void 0);

__decorate([observable], TableDynamicFilterBar.prototype, "expand", void 0);

__decorate([observable], TableDynamicFilterBar.prototype, "searchText", void 0);

__decorate([observable], TableDynamicFilterBar.prototype, "shouldLocateData", void 0);

__decorate([observable], TableDynamicFilterBar.prototype, "showExpandIcon", void 0);

__decorate([action], TableDynamicFilterBar.prototype, "handleClickOut", void 0);

__decorate([autobind], TableDynamicFilterBar.prototype, "handleDataSetValidate", null);

__decorate([autobind], TableDynamicFilterBar.prototype, "setConditionStatus", null);

__decorate([action], TableDynamicFilterBar.prototype, "setOriginalConditionFields", void 0);

__decorate([autobind], TableDynamicFilterBar.prototype, "handleDataSetUpdate", null);

__decorate([autobind], TableDynamicFilterBar.prototype, "handleDataSetCreate", null);

__decorate([autobind], TableDynamicFilterBar.prototype, "initMenuDataSet", null);

__decorate([action], TableDynamicFilterBar.prototype, "handleSelect", void 0);

__decorate([action], TableDynamicFilterBar.prototype, "handleUnSelect", void 0);

__decorate([autobind], TableDynamicFilterBar.prototype, "handleQuery", null);

TableDynamicFilterBar = __decorate([observer], TableDynamicFilterBar);
export default TableDynamicFilterBar;
//# sourceMappingURL=TableDynamicFilterBar.js.map
