import _typeof from "@babel/runtime/helpers/typeof";
import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import { DataToJSON, FieldType } from '../../../data-set/interface';
import { $l } from '../../../locale-context';

function processAxiosConfig() {
  var axiosConfig = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var args = arguments.length > 1 ? arguments[1] : undefined;

  if (typeof axiosConfig === 'function') {
    return axiosConfig(_objectSpread({}, args));
  }

  return axiosConfig;
}

function getTransportConfig(props) {
  var config = props.config,
      type = props.type,
      searchCode = props.searchCode,
      queryDataSet = props.queryDataSet,
      tableFilterAdapter = props.tableFilterAdapter;
  return processAxiosConfig(tableFilterAdapter, {
    type: type,
    config: config,
    searchCode: searchCode,
    queryDataSet: queryDataSet
  });
}

export var ConditionDataSet = function ConditionDataSet() {
  return {
    paging: false,
    fields: [{
      name: 'fieldName',
      type: FieldType.string
    }, {
      name: 'comparator',
      type: FieldType.string,
      defaultValue: 'EQUAL'
    }, {
      name: 'value',
      transformRequest: function transformRequest(value) {
        if (_typeof(value) === 'object') {
          return JSON.stringify(value);
        }

        return value;
      },
      transformResponse: function transformResponse(value) {
        try {
          return JSON.parse(value);
        } catch (e) {
          return value;
        }
      }
    }],
    dataToJSON: DataToJSON.all,
    events: {
      update: function update() {}
    }
  };
};
export var QuickFilterDataSet = function QuickFilterDataSet(_ref) {
  var searchCode = _ref.searchCode,
      queryDataSet = _ref.queryDataSet,
      tableFilterAdapter = _ref.tableFilterAdapter;
  return {
    paging: false,
    autoQuery: false,
    autoLocateFirst: false,
    primaryKey: 'searchId',
    transport: {
      adapter: function adapter(config, type) {
        return getTransportConfig({
          config: config,
          type: type,
          searchCode: searchCode,
          queryDataSet: queryDataSet,
          tableFilterAdapter: tableFilterAdapter
        });
      }
    },
    fields: [{
      name: 'searchName',
      label: $l('Table', 'filter_name'),
      type: 'string',
      maxLength: 20,
      required: true
    }, {
      name: 'searchId',
      type: 'string'
    }, {
      name: 'defaultFlag',
      type: 'boolean',
      falseValue: 0,
      trueValue: 1,
      label: $l('Table', 'set_default')
    }, {
      name: 'searchCode',
      type: 'string',
      defaultValue: searchCode
    }, {
      name: 'conditionList',
      type: 'object'
    }, {
      name: 'saveFilterValue',
      type: 'boolean',
      falseValue: 0,
      trueValue: 1,
      defaultValue: 1,
      // 默认保存筛选值，兼容旧数据
      transformResponse: function transformResponse(value) {
        if (value === 0) {
          return 0;
        }

        return 1;
      },
      label: $l('Table', 'save_filter_value')
    }, {
      // 是否租户默认配置
      name: 'isTenant',
      type: 'boolean',
      falseValue: 0,
      trueValue: 1
    }]
  };
};
//# sourceMappingURL=QuickFilterDataSet.js.map
