import React, { Component, MouseEvent, ReactElement, ReactNode } from 'react';
import ConfigContext, { ConfigContextValue } from '../../../../lib/config-provider/ConfigContext';
import { TableFilterAdapterProps } from '../../../../lib/configure';
import Field, { Fields } from '../../data-set/Field';
import DataSet from '../../data-set/DataSet';
import Record from '../../data-set/Record';
import { ElementProps } from '../../core/ViewComponent';
import { ButtonProps } from '../../button/Button';
import { DynamicFilterBarConfig } from '../Table';
import { TransportProps } from '../../data-set/Transport';
/**
 * 当前数据是否有值并需要选中
 * @param data
 */
export declare function isSelect(data: any): boolean;
export declare function isEqualDynamicProps(originalValue: any, newValue: any, dataSet?: DataSet, record?: Record, name?: string): boolean;
/**
 * 提交副本数据
 * @param data
 */
export declare function omitData(data: any): Pick<any, string | number | symbol>;
/**
 * obj 值使用 JSON 保存、获取赋值转化
 * @param value
 */
export declare function parseValue(value: any): any;
export declare function stringifyValue(value: any): any;
export interface TableDynamicFilterBarProps extends ElementProps {
    dataSet: DataSet;
    queryDataSet?: DataSet;
    queryFields: ReactElement<any>[];
    queryFieldsLimit?: number;
    buttons?: ReactElement<ButtonProps>[];
    summaryBar?: ReactElement<any>;
    dynamicFilterBar?: DynamicFilterBarConfig;
    onQuery?: () => void;
    onReset?: () => void;
    autoQueryAfterReset?: boolean;
    fuzzyQuery?: boolean;
    fuzzyQueryOnly?: boolean;
    fuzzyQueryPlaceholder?: string;
    searchCode?: string;
    autoQuery?: boolean;
    refreshBtn?: boolean;
}
export declare const CONDITIONSTATUS = "__CONDITIONSTATUS__";
export declare const SELECTFIELDS = "__SELECTFIELDS__";
export declare const MENUDATASET = "__MENUDATASET__";
export declare const CONDITIONDATASET = "__CONDITIONDATASET__";
export declare const OPTIONDATASET = "__OPTIONDATASET__";
export declare const FILTERMENUDATASET = "__FILTERMENUDATASET__";
export declare const MENURESULT = "__MENURESULT__";
export declare const SEARCHTEXT = "__SEARCHTEXT__";
export declare const SELECTCHANGE = "__SELECTCHANGE__";
export default class TableDynamicFilterBar extends Component<TableDynamicFilterBarProps> {
    static get contextType(): typeof ConfigContext;
    static defaultProps: {
        queryFieldsLimit: number;
        autoQueryAfterReset: boolean;
        fuzzyQuery: boolean;
        fuzzyQueryOnly: boolean;
        autoQuery: boolean;
        refreshBtn: boolean;
        buttons: never[];
    };
    context: ConfigContextValue;
    get prefixCls(): string;
    get queryFields(): React.ReactElement<any>[];
    moreFields: Field[];
    /**
     * 控制添加筛选下拉显隐
     */
    fieldSelectHidden: boolean;
    /**
     * 收起/展开
     */
    expand: boolean;
    /**
     * 搜索值
     */
    searchText: string;
    shouldLocateData: boolean;
    showExpandIcon: boolean;
    refDropdown: HTMLDivElement | null;
    refSingleWrapper: HTMLDivElement | null;
    refEditors: Map<string, any>;
    originalValue: object;
    originalConditionFields: string[];
    tempFields: Fields;
    isTooltipShown?: boolean;
    constructor(props: any, context: any);
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentWillReceiveProps(nextProps: Readonly<TableDynamicFilterBarProps>): void;
    processDataSetListener(flag: boolean, nextProps?: TableDynamicFilterBarProps): void;
    handleClickOut: (e: any) => void;
    handleDataSetQuery({ dataSet }: {
        dataSet: any;
    }): Promise<false | undefined>;
    /**
     * queryDataSet 查询前校验事件 触发展开动态字段
     * @param dataSet 查询DS
     * @param result
     */
    handleDataSetValidate({ dataSet, result }: {
        dataSet: any;
        result: any;
    }): Promise<void>;
    setConditionStatus(value: any, orglValue?: object): void;
    setOriginalConditionFields: (code: any) => void;
    /**
     * 筛选条件更新 触发表格查询
     */
    handleDataSetUpdate({ record, name, oldValue }: {
        record: any;
        name: any;
        oldValue: any;
    }): Promise<void>;
    /**
     * queryDS 新建，初始勾选值
     */
    handleDataSetCreate(): void;
    /**
     * 初始化勾选值、条件字段
     * @param props
     */
    initConditionFields(props: any): void;
    /**
     * 初始筛选条数据源状态
     */
    initMenuDataSet(): Promise<boolean>;
    /**
     * tableFilterSuffix 预留自定义区域
     */
    renderSuffix(): (JSX.Element | null)[];
    getPrefix(): ReactNode;
    /**
     * 注入 refEditors
     * @param element
     * @param name
     */
    createFields(element: any, name: any): ReactElement;
    /**
     * 判断查询值是否为空
     * @param value
     */
    isEmpty(value: any): boolean;
    get tableFilterAdapter(): TransportProps | TableFilterAdapterProps | null | undefined;
    /**
     * 是否单行操作
     */
    isSingleLineOpt(): boolean;
    /**
     * 勾选
     * @param code
     * @param record
     */
    handleSelect: (code: any, record?: Record | undefined) => void;
    /**
     * 取消勾选
     * @param code
     */
    handleUnSelect: (code: any) => void;
    /**
     * 查询前修改提示及校验定位
     */
    modifiedCheckQuery(): Promise<void>;
    renderRefreshBtn(): ReactNode;
    /**
     * 渲染展开逻辑
     * @param hidden 是否隐藏全部
     */
    getExpandNode(hidden: any): ReactNode;
    /**
     * 渲染模糊搜索
     */
    getFuzzyQuery(): ReactNode;
    /**
     * 渲染重置按钮
     */
    getResetButton(): JSX.Element;
    /**
     * 筛选头
     * fuzzyQuery + quickFilterMenu + resetButton + buttons
     */
    getFilterMenu(): ReactNode;
    /**
     * 查询字段初始顺序
     * 排除动态属性影响
     */
    get originOrderQueryFields(): Field[];
    handleHelpMouseEnter(e: MouseEvent, help: string): void;
    handleHelpMouseLeave(): void;
    renderTooltipHelp(help: any): JSX.Element | undefined;
    /**
     * 渲染查询条
     */
    getQueryBar(): ReactNode;
    handleQuery(collapse?: boolean): Promise<void>;
    render(): JSX.Element | ({} | undefined)[];
}
